EventQuery

Struct EventQuery 

pub struct EventQuery {
    pub filters: Option<Vec<EventFilter>>,
    pub min_sequence_number: Option<u64>,
}

Fields

filters: Option<Vec<EventFilter>>min_sequence_number: Option<u64>

Exclusive read cursor for returned rows.

This affects returned rows only. It does not narrow the full conflict context version reported by query, and it does not narrow the context checked by append_if.

Implementations

Source

impl EventQuery

pub fn all() -> Self

pub fn with_filters( self, filters: impl IntoIterator<Item = EventFilter>, ) -> Self

pub fn for_event_types( event_types: impl IntoIterator<Item = impl Into<String>>, ) -> Self

pub fn with_min_sequence_number(self, min_sequence_number: u64) -> Self