pub struct AppendResult {
pub first_sequence_number: u64,
pub last_sequence_number: u64,
pub committed_count: u64,
}Expand description
Result of one committed append batch.
A successful append always commits one consecutive global sequence range. Failed appends and failed conditional appends must not partially commit any part of the batch, and under the current Rust contract they also must not consume sequence numbers that later successful appends would observe.
Fields
first_sequence_number: u64last_sequence_number: u64committed_count: u64Trait Implementations
Sourceimpl Clone for AppendResult
impl Clone for AppendResult
Sourcefn clone(&self) -> AppendResult
fn clone(&self) -> AppendResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AppendResult
impl Debug for AppendResult
Sourceimpl PartialEq for AppendResult
impl PartialEq for AppendResult
impl Eq for AppendResult
impl StructuralPartialEq for AppendResult